pub struct AcquisitionEstimate { /* private fields */ }Expand description
Two-stage acquisition wait estimate for a fixed pool size.
Implementations
Sourceimpl AcquisitionEstimate
impl AcquisitionEstimate
Sourcepub fn utilisation_rho(&self) -> f64
pub fn utilisation_rho(&self) -> f64
Estimated utilisation ratio.
Sourcepub fn mean_acquisition_wait_ms(&self) -> f64
pub fn mean_acquisition_wait_ms(&self) -> f64
Estimated mean wait to acquire a pool slot in milliseconds.
Sourcepub fn p99_acquisition_wait_ms(&self) -> f64
pub fn p99_acquisition_wait_ms(&self) -> f64
Estimated p99 wait to acquire a pool slot in milliseconds.
Sourcepub fn acquisition_timeout_ms(&self) -> f64
pub fn acquisition_timeout_ms(&self) -> f64
Configured acquisition timeout in milliseconds.
Sourcepub fn timeout_risk(&self) -> bool
pub fn timeout_risk(&self) -> bool
Whether the p99 acquisition wait is at or above the timeout.