pub struct TransactionMix { /* private fields */ }Expand description
A transaction-level workload mix.
Implementations
Sourceimpl TransactionMix
impl TransactionMix
Sourcepub fn new(classes: Vec<TransactionClass>) -> Result<Self, PoolsimError>
pub fn new(classes: Vec<TransactionClass>) -> Result<Self, PoolsimError>
Creates a transaction mix after validating each class.
Errors
Returns PoolsimError::InvalidInput if the mix is empty or a class is invalid.
Sourcepub fn classes(&self) -> &[TransactionClass]
pub fn classes(&self) -> &[TransactionClass]
Classes in this mix.
Sourcepub fn aggregate_workload(&self) -> WorkloadConfig
pub fn aggregate_workload(&self) -> WorkloadConfig
Aggregates the transaction mix into a workload usable by the existing simulator.