pub enum PoolSizeChange {
Increase,
Decrease,
Keep,
}Expand description
Direction of change between the current and recommended pool sizes.
Variants
Increase
The recommendation needs more connections than production currently uses.
Decrease
The recommendation uses fewer connections than production currently uses.
Keep
The recommendation matches the current production pool size.