Erlang-C queueing formulas. Erlang-C queueing helpers used by sizing and sensitivity calculations.
This module is the analytical queueing side of poolsim-core.
It is primarily used when the queue model is M/M/c and provides:
- utilisation (
rho) - wait probability
- mean queue wait
- queue-wait percentiles
When the queue model is M/D/c, the crate falls back to Monte Carlo probing for the quantities that do not have a direct closed-form implementation here.
Functions
- erlang_
c - Computes Erlang-C waiting probability for an M/M/c queue.
- mean_
queue_ wait_ ms - Computes mean queue wait (milliseconds) for an M/M/c queue.
- queue_
wait_ percentile_ ms - Computes queue-wait percentile (milliseconds) for an M/M/c queue.
- utilisation
- Computes utilization (
rho = lambda / (c * mu)).